summaryrefslogtreecommitdiff
path: root/ironic/drivers/ipmi.py
diff options
context:
space:
mode:
authorDevananda van der Veen <devananda.vdv@gmail.com>2013-05-21 18:32:13 -0700
committerDevananda van der Veen <devananda.vdv@gmail.com>2013-05-22 19:55:32 -0700
commitc8354257814bfc73dc01a67bf1f00f48e0dfc393 (patch)
tree2bc1fe6f1516616f595e898480bc5fb7e05a348c /ironic/drivers/ipmi.py
parentae832fe8cfb4e8e3b6e51e2d5c7da67a5d8144db (diff)
downloadironic-c8354257814bfc73dc01a67bf1f00f48e0dfc393.tar.gz
Update driver names and base class.
Also, add (task, node) to the base and fake driver method parameters. Prepares the way for adding TaskManagers in a following patch. Change-Id: I846227b2416445a539f9ac51d86b33ea49d4abcb
Diffstat (limited to 'ironic/drivers/ipmi.py')
-rw-r--r--ironic/drivers/ipmi.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/ironic/drivers/ipmi.py b/ironic/drivers/ipmi.py
index 4ac0f4ca2..c611ccc97 100644
--- a/ironic/drivers/ipmi.py
+++ b/ironic/drivers/ipmi.py
@@ -83,12 +83,12 @@ def _get_console_pid(node_id):
return None
-class IPMIPowerDriver(base.BMCDriver):
+class IPMIPowerDriver(base.ControlDriver):
"""Generic IPMI Power Driver
- This BMCDriver class provides mechanism for controlling the power state
- of physical hardware via IPMI calls. It also provides console access
- for some supported hardware.
+ This ControlDriver class provides mechanism for controlling the power state
+ of physical hardware via IPMI calls. It also provides console access for
+ some supported hardware.
"""
def __init__(self, node, **kwargs):